@@ -42,28 +42,28 @@ draw.quintuple.venn <- function(
 	n1345,
 	n2345,
 	n12345,
-	category = rep("", 5),
+	category = rep('', 5),
 	lwd = rep(2, 5),
-	lty = rep("solid", 5),
-	col = rep("black", 5),
+	lty = rep('solid', 5),
+	col = rep('black', 5),
 	fill = NULL,
 	alpha = rep(0.5, 5),
-	label.col = rep("black", 31),
+	label.col = rep('black', 31),
 	cex = rep(1, 31),
-	fontface = rep("plain", 31),
-	fontfamily = rep("serif", 31),
+	fontface = rep('plain', 31),
+	fontfamily = rep('serif', 31),
 	cat.pos = c(0, 287.5, 215, 145, 70),
 	cat.dist = rep(0.2, 5),
-	cat.col = rep("black", 5),
+	cat.col = rep('black', 5),
 	cat.cex = rep(1, 5),
-	cat.fontface = rep("plain", 5),
-	cat.fontfamily = rep("serif", 5),
+	cat.fontface = rep('plain', 5),
+	cat.fontfamily = rep('serif', 5),
 	cat.just = rep(list(c(0.5, 0.5)), 5),
 	rotation.degree = 0,
 	rotation.centre = c(0.5, 0.5),
 	ind = TRUE,
 	cex.prop=NULL,
-	print.mode = "raw",
+	print.mode = 'raw',
     sigdigs=3,
     direct.area=FALSE,
     area.vector=0,
@@ -73,71 +73,71 @@ draw.quintuple.venn <- function(
 	#area1 > area2 > area3 > area4 > area5
 	# check parameter lengths
 	if (length(category) == 1) { cat <- rep(category, 5); }
-	else if (length(category) != 5) { flog.error("Unexpected parameter length for 'category'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'category'"); }
+	else if (length(category) != 5) { flog.error('Unexpected parameter length for "category"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "category"'); }
 
 	if (length(lwd) == 1) { lwd <- rep(lwd, 5); }
-	else if (length(lwd) != 5) { flog.error("Unexpected parameter length for 'lwd'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'lwd'"); }
+	else if (length(lwd) != 5) { flog.error('Unexpected parameter length for "lwd"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "lwd"'); }
 
 	if (length(lty) == 1) { lty <- rep(lty, 5); }
-	else if (length(lty) != 5) { flog.error("Unexpected parameter length for 'lty'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'lty'"); }
+	else if (length(lty) != 5) { flog.error('Unexpected parameter length for "lty"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "lty"'); }
 
 	if (length(col) == 1) { col <- rep(col, 5); }
-	else if (length(col) != 5) { flog.error("Unexpected parameter length for 'col'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'col'"); }
+	else if (length(col) != 5) { flog.error('Unexpected parameter length for "col"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "col"'); }
 
 	if (length(label.col) == 1) { label.col <- rep(label.col, 31); }
-	else if (length(label.col) != 31) { flog.error("Unexpected parameter length for 'label.col'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'label.col'"); }
+	else if (length(label.col) != 31) { flog.error('Unexpected parameter length for "label.col"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "label.col"'); }
 
 	if (length(cex) == 1) { cex <- rep(cex, 31); }
-	else if (length(cex) != 31) { flog.error("Unexpected parameter length for 'cex'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'cex'"); }
+	else if (length(cex) != 31) { flog.error('Unexpected parameter length for "cex"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "cex"'); }
 
 	if (length(fontface) == 1) { fontface <- rep(fontface, 31); }
-	else if (length(fontface) != 31) { flog.error("Unexpected parameter length for 'fontface'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'fontface'"); }
+	else if (length(fontface) != 31) { flog.error('Unexpected parameter length for "fontface"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "fontface"'); }
 
 	if (length(fontfamily) == 1) { fontfamily <- rep(fontfamily, 31); }
-	else if (length(fontfamily) != 31) { flog.error("Unexpected parameter length for 'fontfamily'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'fontfamily'"); }
+	else if (length(fontfamily) != 31) { flog.error('Unexpected parameter length for "fontfamily"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "fontfamily"'); }
 
 	if (length(fill) == 1) { fill <- rep(fill, 5); }
-	else if (length(fill) != 5 & length(fill) != 0) { flog.error("Unexpected parameter length for 'fill'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'fill'"); }
+	else if (length(fill) != 5 & length(fill) != 0) { flog.error('Unexpected parameter length for "fill"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "fill"'); }
 
 	if (length(alpha) == 1) { alpha <- rep(alpha, 5); }
-	else if (length(alpha) != 5 & length(alpha) != 0) { flog.error("Unexpected parameter length for 'alpha'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'alpha'"); }
+	else if (length(alpha) != 5 & length(alpha) != 0) { flog.error('Unexpected parameter length for "alpha"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "alpha"'); }
 
 	if (length(cat.pos) == 1) { cat.pos <- rep(cat.pos, 5); }
-	else if (length(cat.pos) != 5) { flog.error("Unexpected parameter length for 'cat.pos'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'cat.pos'"); }
+	else if (length(cat.pos) != 5) { flog.error('Unexpected parameter length for "cat.pos"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "cat.pos"'); }
 
 	if (length(cat.dist) == 1) { cat.dist <- rep(cat.dist, 5); }
-	else if (length(cat.dist) != 5) { flog.error("Unexpected parameter length for 'cat.dist'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'cat.dist'"); }
+	else if (length(cat.dist) != 5) { flog.error('Unexpected parameter length for "cat.dist"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "cat.dist"'); }
 
 	if (length(cat.col) == 1) { cat.col <- rep(cat.col, 5); }
-	else if (length(cat.col) != 5) { flog.error("Unexpected parameter length for 'cat.col'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'cat.col'"); }
+	else if (length(cat.col) != 5) { flog.error('Unexpected parameter length for "cat.col"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "cat.col"'); }
 
 	if (length(cat.cex) == 1) { cat.cex <- rep(cat.cex, 5); }
-	else if (length(cat.cex) != 5) { flog.error("Unexpected parameter length for 'cat.cex'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'cat.cex'"); }
+	else if (length(cat.cex) != 5) { flog.error('Unexpected parameter length for "cat.cex"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "cat.cex"'); }
 
 	if (length(cat.fontface) == 1) { cat.fontface <- rep(cat.fontface, 5); }
-	else if (length(cat.fontface) != 5) { flog.error("Unexpected parameter length for 'cat.fontface'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'cat.fontface'"); }
+	else if (length(cat.fontface) != 5) { flog.error('Unexpected parameter length for "cat.fontface"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "cat.fontface"'); }
 
 	if (length(cat.fontfamily) == 1) { cat.fontfamily <- rep(cat.fontfamily, 5); }
-	else if (length(cat.fontfamily) != 5) { flog.error("Unexpected parameter length for 'cat.fontfamily'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'cat.fontfamily'"); }
+	else if (length(cat.fontfamily) != 5) { flog.error('Unexpected parameter length for "cat.fontfamily"",name="VennDiagramLogger')
+stop('Unexpected parameter length for "cat.fontfamily"'); }
 
-	if (!(class(cat.just) == "list" & length(cat.just) == 5 & length(cat.just[[1]]) == 2 & length(cat.just[[2]]) == 2 & length(cat.just[[3]]) == 2 & length(cat.just[[4]]) == 2 & length(cat.just[[5]]) == 2)) { flog.error("Unexpected parameter format for 'cat.just'",name="VennDiagramLogger")
-stop("Unexpected parameter format for 'cat.just'"); }
+	if (!(is.list(cat.just) && length(cat.just) == 5 && length(cat.just[[1]]) == 2 && length(cat.just[[2]]) == 2 && length(cat.just[[3]]) == 2 && length(cat.just[[4]]) == 2 && length(cat.just[[5]]) == 2)) { flog.error('Unexpected parameter format for "cat.just"",name="VennDiagramLogger')
+stop('Unexpected parameter format for "cat.just"'); }
 	cat.pos <- cat.pos + rotation.degree;
 	
 	if(direct.area){
@@ -145,7 +145,7 @@ stop("Unexpected parameter format for 'cat.just'"); }
 		#create the variables and assign their values from the area vector
 		for(i in 1:31)
 		{
-			assign(paste("a",i,sep=""),area.vector[i]);
+			assign(paste('a',i,sep=''),area.vector[i]);
 		}
 	}
 	else{
@@ -186,42 +186,42 @@ stop("Unexpected parameter format for 'cat.just'"); }
 		areas <- c(a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12, a13, a14, a15, a16, a17, a18, a19, a20, a21, a22, a23, a24, a25, a26, a27, a28, a29, a30, a31);
 	}
 	areas.error <- c(
-		"a1 <- area1 - a7 - a8 - a18 - a17 - a19 - a9 - a27 - a28 - a31 - a20 - a30 - a29 - a22 - a23 - a12",
-		"a2 <- area2 - a9 - a10 - a19 - a20 - a21 - a11 - a28 - a29 - a31 - a22 - a30 - a26 - a25 - a24 - a14",
-		"a3 <- area3 - a21 - a11 - a12 - a13 - a29 - a22 - a23 - a24 - a30 - a31 - a26 - a27 - a16 - a6 - a17",
-		"a4 <- area4 - a13 - a14 - a15 - a16 - a23 - a24 - a25 - a26 - a27 - a28 - a31 - a18 - a19 - a8 - a30",
-		"a5 <- area5 - a6 - a7 - a15 - a16 - a17 - a18 - a25 - a26 - a27 - a28 - a31 - a20 - a29 - a21 - a10",
-		"a6 <- n35 - a16 - a17 - a21 - a26 - a27 - a29 - a31",
-		"a7 <- n15 - a17 - a18 - a20 - a27 - a28 - a29 - a31",
-		"a8 <- n14 - a18 - a19 - a23 - a27 - a28 - a30 - a31",
-		"a9 <- n12 - a19 - a20 - a22 - a28 - a29 - a30 - a31",
-		"a10 <- n25 - a20 - a21 - a25 - a26 - a28 - a29 - a31",
-		"a11 <- n23 - a21 - a22 - a24 - a26 - a29 - a30 - a31",
-		"a12 <- n13 - a17 - a22 - a23 - a27 - a29 - a30 - a31",
-		"a13 <- n34 - a16 - a23 - a24 - a26 - a27 - a30 - a31",
-		"a14 <- n24 - a19 - a24 - a25 - a30 - a28 - a26 - a31",
-		"a15 <- n45 - a18 - a25 - a16 - a28 - a27 - a26 - a31",
-		"a16 <- n345 - a26 - a27 - a31",
-		"a17 <- n135 - a27 - a29 - a31",
-		"a18 <- n145 - a27 - a28 - a31",
-		"a19 <- n124 - a28 - a30 - a31",
-		"a20 <- n125 - a28 - a29 - a31",
-		"a21 <- n235 - a26 - a29 - a31",
-		"a22 <- n123 - a29 - a30 - a31",
-		"a23 <- n134 - a27 - a30 - a31",
-		"a24 <- n234 - a26 - a30 - a31",
-		"a25 <- n245 - a26 - a28 - a31",
-		"a26 <- n2345 - a31",
-		"a27 <- n1345 - a31",
-		"a28 <- n1245 - a31",
-		"a29 <- n1235 - a31",
-		"a30 <- n1234 - a31",
-		"a31 <- n12345"
+		'a1 <- area1 - a7 - a8 - a18 - a17 - a19 - a9 - a27 - a28 - a31 - a20 - a30 - a29 - a22 - a23 - a12',
+		'a2 <- area2 - a9 - a10 - a19 - a20 - a21 - a11 - a28 - a29 - a31 - a22 - a30 - a26 - a25 - a24 - a14',
+		'a3 <- area3 - a21 - a11 - a12 - a13 - a29 - a22 - a23 - a24 - a30 - a31 - a26 - a27 - a16 - a6 - a17',
+		'a4 <- area4 - a13 - a14 - a15 - a16 - a23 - a24 - a25 - a26 - a27 - a28 - a31 - a18 - a19 - a8 - a30',
+		'a5 <- area5 - a6 - a7 - a15 - a16 - a17 - a18 - a25 - a26 - a27 - a28 - a31 - a20 - a29 - a21 - a10',
+		'a6 <- n35 - a16 - a17 - a21 - a26 - a27 - a29 - a31',
+		'a7 <- n15 - a17 - a18 - a20 - a27 - a28 - a29 - a31',
+		'a8 <- n14 - a18 - a19 - a23 - a27 - a28 - a30 - a31',
+		'a9 <- n12 - a19 - a20 - a22 - a28 - a29 - a30 - a31',
+		'a10 <- n25 - a20 - a21 - a25 - a26 - a28 - a29 - a31',
+		'a11 <- n23 - a21 - a22 - a24 - a26 - a29 - a30 - a31',
+		'a12 <- n13 - a17 - a22 - a23 - a27 - a29 - a30 - a31',
+		'a13 <- n34 - a16 - a23 - a24 - a26 - a27 - a30 - a31',
+		'a14 <- n24 - a19 - a24 - a25 - a30 - a28 - a26 - a31',
+		'a15 <- n45 - a18 - a25 - a16 - a28 - a27 - a26 - a31',
+		'a16 <- n345 - a26 - a27 - a31',
+		'a17 <- n135 - a27 - a29 - a31',
+		'a18 <- n145 - a27 - a28 - a31',
+		'a19 <- n124 - a28 - a30 - a31',
+		'a20 <- n125 - a28 - a29 - a31',
+		'a21 <- n235 - a26 - a29 - a31',
+		'a22 <- n123 - a29 - a30 - a31',
+		'a23 <- n134 - a27 - a30 - a31',
+		'a24 <- n234 - a26 - a30 - a31',
+		'a25 <- n245 - a26 - a28 - a31',
+		'a26 <- n2345 - a31',
+		'a27 <- n1345 - a31',
+		'a28 <- n1245 - a31',
+		'a29 <- n1235 - a31',
+		'a30 <- n1234 - a31',
+		'a31 <- n12345'
 		);
 	for (i in 1:length(areas)) {
 		if (areas[i] < 0) {
-			flog.error(paste("Impossible:", areas.error[i], "produces negative area"),name="VennDiagramLogger")
-stop(paste("Impossible:", areas.error[i], "produces negative area"));
+			flog.error(paste('Impossible:', areas.error[i], 'produces negative area'),name='VennDiagramLogger')
+stop(paste('Impossible:', areas.error[i], 'produces negative area'));
 			}
 		}
 
@@ -229,29 +229,29 @@ stop(paste("Impossible:", areas.error[i], "produces negative area"));
         if(length(cex.prop) > 0){
 
             if(length(cex.prop) != 1) {
-		flog.error("Value passed to cex.prop is not length 1",name="VennDiagramLogger")
-		stop("Value passed to cex.prop is not length 1")
+		flog.error('Value passed to cex.prop is not length 1',name='VennDiagramLogger')
+		stop('Value passed to cex.prop is not length 1')
 		}
 
             ## figure out what function to use
             func = cex.prop
-            if(class(cex.prop) != "function"){
-                if(cex.prop == "lin"){
+            if (!is(cex.prop, 'function')) {
+                if(cex.prop == 'lin'){
                     func = function(x) x
                 }
-                else if(cex.prop == "log10"){
+                else if(cex.prop == 'log10'){
                     func = log10
                 }
-                else flog.error(paste0("Unknown value passed to cex.prop: ", cex.prop),name="VennDiagramLogger")
-stop(paste0("Unknown value passed to cex.prop: ", cex.prop))
+                else flog.error(paste0('Unknown value passed to cex.prop: ', cex.prop),name='VennDiagramLogger')
+stop(paste0('Unknown value passed to cex.prop: ', cex.prop))
             }
 
             ## rescale areas
             maxArea = max(areas)            
             for(i in 1:length(areas)){                
                 cex[i] = cex[i] * func(areas[i]) / func(maxArea)
-                if(cex[i] <= 0) stop(paste0("Error in rescaling of area labels: the label of area ",
-                          i, " is less than or equal to zero"))
+                if(cex[i] <= 0) stop(paste0('Error in rescaling of area labels: the label of area ',
+                          i, ' is less than or equal to zero'))
             }
         }
 
@@ -379,19 +379,19 @@ stop(paste0("Unknown value passed to cex.prop: ", cex.prop))
 	label.matrix[30,] <- c(a30, 0.5220, 0.2730);
 	label.matrix[31,] <- c(a31, 0.5000, 0.5000);
 
-	processedLabels <- rep("",length(label.matrix[,'label']));
-    if(print.mode[1] == "percent"){
-			processedLabels <- paste(signif(label.matrix[,'label']/sum(label.matrix[,'label'])*100,digits=sigdigs),"%",sep="");
-			if(isTRUE(print.mode[2] == "raw"))
+	processedLabels <- rep('',length(label.matrix[,'label']));
+    if(print.mode[1] == 'percent'){
+			processedLabels <- paste(signif(label.matrix[,'label']/sum(label.matrix[,'label'])*100,digits=sigdigs),'%',sep='');
+			if(isTRUE(print.mode[2] == 'raw'))
 			{
-				processedLabels <- paste(processedLabels,"\n(",label.matrix[,'label'],")",sep="");
+				processedLabels <- paste(processedLabels,'\n(',label.matrix[,'label'],')',sep='');
 			}
 		}
-	if(print.mode[1] == "raw"){
+	if(print.mode[1] == 'raw'){
 			processedLabels <- label.matrix[,'label'];
-			if(isTRUE(print.mode[2] == "percent"))
+			if(isTRUE(print.mode[2] == 'percent'))
 			{
-				processedLabels <- paste(processedLabels,"\n(",paste(signif(label.matrix[,'label']/sum(label.matrix[,'label'])*100,digits=sigdigs),"%)",sep=""),sep="");
+				processedLabels <- paste(processedLabels,'\n(',paste(signif(label.matrix[,'label']/sum(label.matrix[,'label'])*100,digits=sigdigs),'%)',sep=''),sep='');
 			}
 		}
 
@@ -443,10 +443,11 @@ stop(paste0("Unknown value passed to cex.prop: ", cex.prop))
 			);
 		}
 
-	#if (exists("margin")) {margin <- margin + 0.05} else {margin <- 0.05}
+	#if (exists('margin')) {margin <- margin + 0.05} else {margin <- 0.05}
 
 	# adjust grob.list to fit and return grob.list
 	grob.list <- VennDiagram::adjust.venn(VennDiagram::rotate.venn.degrees(grob.list, rotation.degree, rotation.centre[1], rotation.centre[2]), ...);
 	if (ind) { grid.draw(grob.list); }
+	class(grob.list) <- c('VennDiagram', class(grob.list));
 	return(grob.list);
 	}
