@@ -120,7 +120,7 @@ stop('Unexpected parameter length for "cat.fontface"'); }
 	else if (length(cat.fontfamily) != 3) { flog.error('Unexpected parameter length for "cat.fontfamily"',name='VennDiagramLogger')
 stop('Unexpected parameter length for "cat.fontfamily"'); }
 
-	if (!(class(cat.just) == 'list' & length(cat.just) == 3)) { flog.error('Unexpected parameter format for "cat.just"',name='VennDiagramLogger')
+	if (!(is.list(cat.just) & length(cat.just) == 3)) { flog.error('Unexpected parameter format for "cat.just"',name='VennDiagramLogger')
 stop('Unexpected parameter format for "cat.just"'); }
 	else if (!(length(cat.just[[1]]) == 2 & length(cat.just[[2]]) == 2 & length(cat.just[[3]]) == 2)) { flog.error('Unexpected parameter format for "cat.just',name='VennDiagramLogger')
 stop('Unexpected parameter format for "cat.just"'); }
@@ -477,7 +477,7 @@ stop(paste('Impossible:', areas.error[i], 'produces negative area'));
 
             ## figure out what function to use
             func = cex.prop
-            if(class(cex.prop) != 'function'){
+            if (!is(cex.prop, 'function')) {
                 if(cex.prop == 'lin'){
                     func = function(x) x
                 }
@@ -590,5 +590,6 @@ stop('Invalid setting of cat.default.pos');
 
 	# draw diagram before returning gList is specified by user
 	if (ind) { grid.draw(grob.list); }
+	class(grob.list) <- c('VennDiagram', class(grob.list));
 	return(grob.list);
 	}
